@@ -20,8 +20,8 @@ The main observations to make are:
 While these examples give some intuition about the
 algorithms, this intuition might not apply to very high
 dimensional data.
+
 """
-print(__doc__)
 
 import time
 import warnings
@@ -40,9 +40,8 @@ np.random.seed(0)
 # of the algorithms, but not too big to avoid too long running times
 
 n_samples = 1500
-noisy_circles = datasets.make_circles(n_samples=n_samples, factor=.5,
-                                      noise=.05)
-noisy_moons = datasets.make_moons(n_samples=n_samples, noise=.05)
+noisy_circles = datasets.make_circles(n_samples=n_samples, factor=0.5, noise=0.05)
+noisy_moons = datasets.make_moons(n_samples=n_samples, noise=0.05)
 blobs = datasets.make_blobs(n_samples=n_samples, random_state=8)
 no_structure = np.random.rand(n_samples, 2), None
 
@@ -54,30 +53,31 @@ X_aniso = np.dot(X, transformation)
 aniso = (X_aniso, y)
 
 # blobs with varied variances
-varied = datasets.make_blobs(n_samples=n_samples,
-                             cluster_std=[1.0, 2.5, 0.5],
-                             random_state=random_state)
+varied = datasets.make_blobs(
+    n_samples=n_samples, cluster_std=[1.0, 2.5, 0.5], random_state=random_state
+)
 
 # %%
 # Run the clustering and plot
 
 # Set up cluster parameters
 plt.figure(figsize=(9 * 1.3 + 2, 14.5))
-plt.subplots_adjust(left=.02, right=.98, bottom=.001, top=.96, wspace=.05,
-                    hspace=.01)
+plt.subplots_adjust(
+    left=0.02, right=0.98, bottom=0.001, top=0.96, wspace=0.05, hspace=0.01
+)
 
 plot_num = 1
 
-default_base = {'n_neighbors': 10,
-                'n_clusters': 3}
+default_base = {"n_neighbors": 10, "n_clusters": 3}
 
 datasets = [
-    (noisy_circles, {'n_clusters': 2}),
-    (noisy_moons, {'n_clusters': 2}),
-    (varied, {'n_neighbors': 2}),
-    (aniso, {'n_neighbors': 2}),
+    (noisy_circles, {"n_clusters": 2}),
+    (noisy_moons, {"n_clusters": 2}),
+    (varied, {"n_neighbors": 2}),
+    (aniso, {"n_neighbors": 2}),
     (blobs, {}),
-    (no_structure, {})]
+    (no_structure, {}),
+]
 
 for i_dataset, (dataset, algo_params) in enumerate(datasets):
     # update parameters with dataset-specific values
@@ -93,19 +93,23 @@ for i_dataset, (dataset, algo_params) in enumerate(datasets):
     # Create cluster objects
     # ============
     ward = cluster.AgglomerativeClustering(
-        n_clusters=params['n_clusters'], linkage='ward')
+        n_clusters=params["n_clusters"], linkage="ward"
+    )
     complete = cluster.AgglomerativeClustering(
-        n_clusters=params['n_clusters'], linkage='complete')
+        n_clusters=params["n_clusters"], linkage="complete"
+    )
     average = cluster.AgglomerativeClustering(
-        n_clusters=params['n_clusters'], linkage='average')
+        n_clusters=params["n_clusters"], linkage="average"
+    )
     single = cluster.AgglomerativeClustering(
-        n_clusters=params['n_clusters'], linkage='single')
+        n_clusters=params["n_clusters"], linkage="single"
+    )
 
     clustering_algorithms = (
-        ('Single Linkage', single),
-        ('Average Linkage', average),
-        ('Complete Linkage', complete),
-        ('Ward Linkage', ward),
+        ("Single Linkage", single),
+        ("Average Linkage", average),
+        ("Complete Linkage", complete),
+        ("Ward Linkage", ward),
     )
 
     for name, algorithm in clustering_algorithms:
@@ -115,14 +119,15 @@ for i_dataset, (dataset, algo_params) in enumerate(datasets):
         with warnings.catch_warnings():
             warnings.filterwarnings(
                 "ignore",
-                message="the number of connected components of the " +
-                "connectivity matrix is [0-9]{1,2}" +
-                " > 1. Completing it to avoid stopping the tree early.",
-                category=UserWarning)
+                message="the number of connected components of the "
+                + "connectivity matrix is [0-9]{1,2}"
+                + " > 1. Completing it to avoid stopping the tree early.",
+                category=UserWarning,
+            )
             algorithm.fit(X)
 
         t1 = time.time()
-        if hasattr(algorithm, 'labels_'):
+        if hasattr(algorithm, "labels_"):
             y_pred = algorithm.labels_.astype(int)
         else:
             y_pred = algorithm.predict(X)
@@ -131,19 +136,40 @@ for i_dataset, (dataset, algo_params) in enumerate(datasets):
         if i_dataset == 0:
             plt.title(name, size=18)
 
-        colors = np.array(list(islice(cycle(['#377eb8', '#ff7f00', '#4daf4a',
-                                             '#f781bf', '#a65628', '#984ea3',
-                                             '#999999', '#e41a1c', '#dede00']),
-                                      int(max(y_pred) + 1))))
+        colors = np.array(
+            list(
+                islice(
+                    cycle(
+                        [
+                            "#377eb8",
+                            "#ff7f00",
+                            "#4daf4a",
+                            "#f781bf",
+                            "#a65628",
+                            "#984ea3",
+                            "#999999",
+                            "#e41a1c",
+                            "#dede00",
+                        ]
+                    ),
+                    int(max(y_pred) + 1),
+                )
+            )
+        )
         plt.scatter(X[:, 0], X[:, 1], s=10, color=colors[y_pred])
 
         plt.xlim(-2.5, 2.5)
         plt.ylim(-2.5, 2.5)
         plt.xticks(())
         plt.yticks(())
-        plt.text(.99, .01, ('%.2fs' % (t1 - t0)).lstrip('0'),
-                 transform=plt.gca().transAxes, size=15,
-                 horizontalalignment='right')
+        plt.text(
+            0.99,
+            0.01,
+            ("%.2fs" % (t1 - t0)).lstrip("0"),
+            transform=plt.gca().transAxes,
+            size=15,
+            horizontalalignment="right",
+        )
         plot_num += 1
 
 plt.show()
