@@ -13,7 +13,8 @@ scale the numeric features and one-hot encode the categorical ones.
 
 In this example, the numeric data is standard-scaled after mean-imputation. The
 categorical data is one-hot encoded via ``OneHotEncoder``, which
-creates a new category for missing values.
+creates a new category for missing values. We further reduce the dimensionality
+by selecting categories using a chi-squared test.
 
 In addition, we show two different ways to dispatch the columns to the
 particular pre-processor: by column names and by column data types.
@@ -37,7 +38,8 @@ from sklearn.pipeline import Pipeline
 from sklearn.impute import SimpleImputer
 from sklearn.preprocessing import StandardScaler, OneHotEncoder
 from sklearn.linear_model import LogisticRegression
-from sklearn.model_selection import train_test_split, GridSearchCV
+from sklearn.model_selection import train_test_split, RandomizedSearchCV
+from sklearn.feature_selection import SelectPercentile, chi2
 
 np.random.seed(0)
 
@@ -77,8 +79,12 @@ numeric_transformer = Pipeline(
 )
 
 categorical_features = ["embarked", "sex", "pclass"]
-categorical_transformer = OneHotEncoder(handle_unknown="ignore")
-
+categorical_transformer = Pipeline(
+    steps=[
+        ("encoder", OneHotEncoder(handle_unknown="ignore")),
+        ("selector", SelectPercentile(chi2, percentile=50)),
+    ]
+)
 preprocessor = ColumnTransformer(
     transformers=[
         ("num", numeric_transformer, numeric_features),
@@ -173,40 +179,46 @@ selector(dtype_include="category")(X_train)
 # hyperparameters as part of the ``Pipeline``.
 # We will search for both the imputer strategy of the numeric preprocessing
 # and the regularization parameter of the logistic regression using
-# :class:`~sklearn.model_selection.GridSearchCV`.
+# :class:`~sklearn.model_selection.RandomizedSearchCV`. This
+# hyperparameter search randomly selects a fixed number of parameter
+# settings configured by `n_iter`. Alternatively, one can use
+# :class:`~sklearn.model_selection.GridSearchCV` but the cartesian product of
+# the parameter space will be evaluated.
 
 param_grid = {
     "preprocessor__num__imputer__strategy": ["mean", "median"],
+    "preprocessor__cat__selector__percentile": [10, 30, 50, 70],
     "classifier__C": [0.1, 1.0, 10, 100],
 }
 
-grid_search = GridSearchCV(clf, param_grid, cv=10)
-grid_search
+search_cv = RandomizedSearchCV(clf, param_grid, n_iter=10, random_state=0)
+search_cv
 
 # %%
 # Calling 'fit' triggers the cross-validated search for the best
 # hyper-parameters combination:
 #
-grid_search.fit(X_train, y_train)
+search_cv.fit(X_train, y_train)
 
 print("Best params:")
-print(grid_search.best_params_)
+print(search_cv.best_params_)
 
 # %%
 # The internal cross-validation scores obtained by those parameters is:
-print(f"Internal CV score: {grid_search.best_score_:.3f}")
+print(f"Internal CV score: {search_cv.best_score_:.3f}")
 
 # %%
 # We can also introspect the top grid search results as a pandas dataframe:
 import pandas as pd
 
-cv_results = pd.DataFrame(grid_search.cv_results_)
+cv_results = pd.DataFrame(search_cv.cv_results_)
 cv_results = cv_results.sort_values("mean_test_score", ascending=False)
 cv_results[
     [
         "mean_test_score",
         "std_test_score",
         "param_preprocessor__num__imputer__strategy",
+        "param_preprocessor__cat__selector__percentile",
         "param_classifier__C",
     ]
 ].head(5)
@@ -217,8 +229,6 @@ cv_results[
 # not used for hyperparameter tuning.
 #
 print(
-    (
-        "best logistic regression from grid search: %.3f"
-        % grid_search.score(X_test, y_test)
-    )
+    "accuracy of the best model from randomized search: "
+    f"{search_cv.score(X_test, y_test):.3f}"
 )
