@@ -14,14 +14,13 @@ non-Gaussian processes.
 
 """
 
+# %%
+# Generate sample data
+# --------------------
+
 import numpy as np
-import matplotlib.pyplot as plt
 from scipy import signal
 
-from sklearn.decomposition import FastICA, PCA
-
-# #############################################################################
-# Generate sample data
 np.random.seed(0)
 n_samples = 2000
 time = np.linspace(0, 8, n_samples)
@@ -38,8 +37,14 @@ S /= S.std(axis=0)  # Standardize data
 A = np.array([[1, 1, 1], [0.5, 2, 1.0], [1.5, 1.0, 2.0]])  # Mixing matrix
 X = np.dot(S, A.T)  # Generate observations
 
+# %%
+# Fit ICA and PCA models
+# ----------------------
+
+from sklearn.decomposition import FastICA, PCA
+
 # Compute ICA
-ica = FastICA(n_components=3)
+ica = FastICA(n_components=3, whiten="arbitrary-variance")
 S_ = ica.fit_transform(X)  # Reconstruct signals
 A_ = ica.mixing_  # Get estimated mixing matrix
 
@@ -50,8 +55,11 @@ assert np.allclose(X, np.dot(S_, A_.T) + ica.mean_)
 pca = PCA(n_components=3)
 H = pca.fit_transform(X)  # Reconstruct signals based on orthogonal components
 
-# #############################################################################
+# %%
 # Plot results
+# ------------
+
+import matplotlib.pyplot as plt
 
 plt.figure()
 
