@@ -1,6 +1,4 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 """
 =========================================================
 Linear Regression Example
@@ -14,14 +12,12 @@ and the responses predicted by the linear approximation.
 
 The coefficients, residual sum of squares and the coefficient of
 determination are also calculated.
-"""
-print(__doc__)
 
+"""
 
 # Code source: Jaques Grobler
 # License: BSD 3 clause
 
-
 import matplotlib.pyplot as plt
 import numpy as np
 from sklearn import datasets, linear_model
@@ -51,17 +47,15 @@ regr.fit(diabetes_X_train, diabetes_y_train)
 diabetes_y_pred = regr.predict(diabetes_X_test)
 
 # The coefficients
-print('Coefficients: \n', regr.coef_)
+print("Coefficients: \n", regr.coef_)
 # The mean squared error
-print('Mean squared error: %.2f'
-      % mean_squared_error(diabetes_y_test, diabetes_y_pred))
+print("Mean squared error: %.2f" % mean_squared_error(diabetes_y_test, diabetes_y_pred))
 # The coefficient of determination: 1 is perfect prediction
-print('Coefficient of determination: %.2f'
-      % r2_score(diabetes_y_test, diabetes_y_pred))
+print("Coefficient of determination: %.2f" % r2_score(diabetes_y_test, diabetes_y_pred))
 
 # Plot outputs
-plt.scatter(diabetes_X_test, diabetes_y_test,  color='black')
-plt.plot(diabetes_X_test, diabetes_y_pred, color='blue', linewidth=3)
+plt.scatter(diabetes_X_test, diabetes_y_test, color="black")
+plt.plot(diabetes_X_test, diabetes_y_pred, color="blue", linewidth=3)
 
 plt.xticks(())
 plt.yticks(())
