@@ -7,19 +7,18 @@ Sparsity Example: Fitting only features 1  and 2
 Features 1 and 2 of the diabetes-dataset are fitted and
 plotted below. It illustrates that although feature 2
 has a strong coefficient on the full model, it does not
-give us much regarding `y` when compared to just feature 1
-
+give us much regarding `y` when compared to just feature 1.
 """
 
 # Code source: Gaël Varoquaux
 # Modified for documentation by Jaques Grobler
 # License: BSD 3 clause
 
-import matplotlib.pyplot as plt
-import numpy as np
-from mpl_toolkits.mplot3d import Axes3D
+# %%
+# First we load the diabetes dataset.
 
-from sklearn import datasets, linear_model
+from sklearn import datasets
+import numpy as np
 
 X, y = datasets.load_diabetes(return_X_y=True)
 indices = (0, 1)
@@ -29,16 +28,28 @@ X_test = X[-20:, indices]
 y_train = y[:-20]
 y_test = y[-20:]
 
+# %%
+# Next we fit a linear regression model.
+
+from sklearn import linear_model
+
 ols = linear_model.LinearRegression()
-ols.fit(X_train, y_train)
+_ = ols.fit(X_train, y_train)
+
+
+# %%
+# Finally we plot the figure from three different views.
+
+import matplotlib.pyplot as plt
+
+# unused but required import for doing 3d projections with matplotlib < 3.2
+import mpl_toolkits.mplot3d  # noqa: F401
 
 
-# #############################################################################
-# Plot the figure
 def plot_figs(fig_num, elev, azim, X_train, clf):
     fig = plt.figure(fig_num, figsize=(4, 3))
     plt.clf()
-    ax = Axes3D(fig, elev=elev, azim=azim)
+    ax = fig.add_subplot(111, projection="3d", elev=elev, azim=azim)
 
     ax.scatter(X_train[:, 0], X_train[:, 1], y_train, c="k", marker="+")
     ax.plot_surface(
@@ -52,9 +63,9 @@ def plot_figs(fig_num, elev, azim, X_train, clf):
     ax.set_xlabel("X_1")
     ax.set_ylabel("X_2")
     ax.set_zlabel("Y")
-    ax.w_xaxis.set_ticklabels([])
-    ax.w_yaxis.set_ticklabels([])
-    ax.w_zaxis.set_ticklabels([])
+    ax.xaxis.set_ticklabels([])
+    ax.yaxis.set_ticklabels([])
+    ax.zaxis.set_ticklabels([])
 
 
 # Generate the three different figures from different views
