@@ -28,7 +28,6 @@ representation of the data in the low-dimensional space.
 #
 # We start by generating the S-curve dataset.
 
-from numpy.random import RandomState
 import matplotlib.pyplot as plt
 from matplotlib import ticker
 
@@ -37,10 +36,8 @@ import mpl_toolkits.mplot3d  # noqa: F401
 
 from sklearn import manifold, datasets
 
-rng = RandomState(0)
-
 n_samples = 1500
-S_points, S_color = datasets.make_s_curve(n_samples, random_state=rng)
+S_points, S_color = datasets.make_s_curve(n_samples, random_state=0)
 
 # %%
 # Let's look at the original data. Also define some helping
@@ -110,7 +107,7 @@ params = {
     "n_neighbors": n_neighbors,
     "n_components": n_components,
     "eigen_solver": "auto",
-    "random_state": rng,
+    "random_state": 0,
 }
 
 lle_standard = manifold.LocallyLinearEmbedding(method="standard", **params)
@@ -122,7 +119,7 @@ S_ltsa = lle_ltsa.fit_transform(S_points)
 lle_hessian = manifold.LocallyLinearEmbedding(method="hessian", **params)
 S_hessian = lle_hessian.fit_transform(S_points)
 
-lle_mod = manifold.LocallyLinearEmbedding(method="modified", modified_tol=0.8, **params)
+lle_mod = manifold.LocallyLinearEmbedding(method="modified", **params)
 S_mod = lle_mod.fit_transform(S_points)
 
 # %%
@@ -166,7 +163,11 @@ plot_2d(S_isomap, S_color, "Isomap Embedding")
 # Read more in the :ref:`User Guide <multidimensional_scaling>`.
 
 md_scaling = manifold.MDS(
-    n_components=n_components, max_iter=50, n_init=4, random_state=rng
+    n_components=n_components,
+    max_iter=50,
+    n_init=4,
+    random_state=0,
+    normalized_stress=False,
 )
 S_scaling = md_scaling.fit_transform(S_points)
 
@@ -199,12 +200,13 @@ plot_2d(S_spectral, S_color, "Spectral Embedding")
 
 t_sne = manifold.TSNE(
     n_components=n_components,
-    learning_rate="auto",
     perplexity=30,
-    n_iter=250,
     init="random",
-    random_state=rng,
+    n_iter=250,
+    random_state=0,
 )
 S_t_sne = t_sne.fit_transform(S_points)
 
 plot_2d(S_t_sne, S_color, "T-distributed Stochastic  \n Neighbor Embedding")
+
+# %%
