@@ -18,7 +18,6 @@ points are a subset of the training input observations and their matching
 target values are computed by the isotonic non-parametric fit.
 
 """
-print(__doc__)
 
 # Author: Nelle Varoquaux <nelle.varoquaux@gmail.com>
 #         Alexandre Gramfort <alexandre.gramfort@inria.fr>
@@ -35,7 +34,7 @@ from sklearn.utils import check_random_state
 n = 100
 x = np.arange(n)
 rs = check_random_state(0)
-y = rs.randint(-50, 50, size=(n,)) + 50. * np.log1p(np.arange(n))
+y = rs.randint(-50, 50, size=(n,)) + 50.0 * np.log1p(np.arange(n))
 
 # %%
 # Fit IsotonicRegression and LinearRegression models:
@@ -56,16 +55,16 @@ lc.set_linewidths(np.full(n, 0.5))
 
 fig, (ax0, ax1) = plt.subplots(ncols=2, figsize=(12, 6))
 
-ax0.plot(x, y, 'C0.', markersize=12)
-ax0.plot(x, y_, 'C1.-', markersize=12)
-ax0.plot(x, lr.predict(x[:, np.newaxis]), 'C2-')
+ax0.plot(x, y, "C0.", markersize=12)
+ax0.plot(x, y_, "C1.-", markersize=12)
+ax0.plot(x, lr.predict(x[:, np.newaxis]), "C2-")
 ax0.add_collection(lc)
-ax0.legend(('Training data', 'Isotonic fit', 'Linear fit'), loc='lower right')
-ax0.set_title('Isotonic regression fit on noisy data (n=%d)' % n)
+ax0.legend(("Training data", "Isotonic fit", "Linear fit"), loc="lower right")
+ax0.set_title("Isotonic regression fit on noisy data (n=%d)" % n)
 
 x_test = np.linspace(-10, 110, 1000)
-ax1.plot(x_test, ir.predict(x_test), 'C1-')
-ax1.plot(ir.X_thresholds_, ir.y_thresholds_, 'C1.', markersize=12)
+ax1.plot(x_test, ir.predict(x_test), "C1-")
+ax1.plot(ir.X_thresholds_, ir.y_thresholds_, "C1.", markersize=12)
 ax1.set_title("Prediction function (%d thresholds)" % len(ir.X_thresholds_))
 
 plt.show()
