@@ -5,6 +5,7 @@
 # License: BSD 3 clause
 
 import pytest
+import warnings
 
 import numpy as np
 from scipy import sparse
@@ -12,10 +13,7 @@ from scipy import linalg
 
 from sklearn.utils._testing import assert_array_almost_equal
 from sklearn.utils._testing import assert_array_equal
-from sklearn.utils._testing import assert_almost_equal
 from sklearn.utils._testing import assert_allclose
-from sklearn.utils import check_random_state
-from sklearn.utils.fixes import parse_version
 
 from sklearn.linear_model import LinearRegression
 from sklearn.linear_model._base import _deprecate_normalize
@@ -26,8 +24,8 @@ from sklearn.datasets import make_sparse_uncorrelated
 from sklearn.datasets import make_regression
 from sklearn.datasets import load_iris
 from sklearn.preprocessing import StandardScaler
+from sklearn.preprocessing import add_dummy_feature
 
-rng = np.random.RandomState(0)
 rtol = 1e-6
 
 
@@ -55,45 +53,43 @@ def test_linear_regression():
     assert_array_almost_equal(reg.predict(X), [0])
 
 
-def test_linear_regression_sample_weights():
-    # TODO: loop over sparse data as well
-
-    rng = np.random.RandomState(0)
+@pytest.mark.parametrize("array_constr", [np.array, sparse.csr_matrix])
+@pytest.mark.parametrize("fit_intercept", [True, False])
+def test_linear_regression_sample_weights(
+    array_constr, fit_intercept, global_random_seed
+):
+    rng = np.random.RandomState(global_random_seed)
 
     # It would not work with under-determined systems
-    for n_samples, n_features in ((6, 5),):
+    n_samples, n_features = 6, 5
 
-        y = rng.randn(n_samples)
-        X = rng.randn(n_samples, n_features)
-        sample_weight = 1.0 + rng.rand(n_samples)
+    X = array_constr(rng.normal(size=(n_samples, n_features)))
+    y = rng.normal(size=n_samples)
 
-        for intercept in (True, False):
+    sample_weight = 1.0 + rng.uniform(size=n_samples)
 
-            # LinearRegression with explicit sample_weight
-            reg = LinearRegression(fit_intercept=intercept)
-            reg.fit(X, y, sample_weight=sample_weight)
-            coefs1 = reg.coef_
-            inter1 = reg.intercept_
+    # LinearRegression with explicit sample_weight
+    reg = LinearRegression(fit_intercept=fit_intercept)
+    reg.fit(X, y, sample_weight=sample_weight)
+    coefs1 = reg.coef_
+    inter1 = reg.intercept_
 
-            assert reg.coef_.shape == (X.shape[1],)  # sanity checks
-            assert reg.score(X, y) > 0.5
+    assert reg.coef_.shape == (X.shape[1],)  # sanity checks
 
-            # Closed form of the weighted least square
-            # theta = (X^T W X)^(-1) * X^T W y
-            W = np.diag(sample_weight)
-            if intercept is False:
-                X_aug = X
-            else:
-                dummy_column = np.ones(shape=(n_samples, 1))
-                X_aug = np.concatenate((dummy_column, X), axis=1)
+    # Closed form of the weighted least square
+    # theta = (X^T W X)^(-1) @ X^T W y
+    W = np.diag(sample_weight)
+    X_aug = X if not fit_intercept else add_dummy_feature(X)
 
-            coefs2 = linalg.solve(X_aug.T.dot(W).dot(X_aug), X_aug.T.dot(W).dot(y))
+    Xw = X_aug.T @ W @ X_aug
+    yw = X_aug.T @ W @ y
+    coefs2 = linalg.solve(Xw, yw)
 
-            if intercept is False:
-                assert_array_almost_equal(coefs1, coefs2)
-            else:
-                assert_array_almost_equal(coefs1, coefs2[1:])
-                assert_almost_equal(inter1, coefs2[0])
+    if not fit_intercept:
+        assert_allclose(coefs1, coefs2)
+    else:
+        assert_allclose(coefs1, coefs2[1:])
+        assert_allclose(inter1, coefs2[0])
 
 
 def test_raises_value_error_if_positive_and_sparse():
@@ -108,25 +104,22 @@ def test_raises_value_error_if_positive_and_sparse():
         reg.fit(X, y)
 
 
-def test_raises_value_error_if_sample_weights_greater_than_1d():
+@pytest.mark.parametrize("n_samples, n_features", [(2, 3), (3, 2)])
+def test_raises_value_error_if_sample_weights_greater_than_1d(n_samples, n_features):
     # Sample weights must be either scalar or 1D
+    rng = np.random.RandomState(0)
+    X = rng.randn(n_samples, n_features)
+    y = rng.randn(n_samples)
+    sample_weights_OK = rng.randn(n_samples) ** 2 + 1
+    sample_weights_OK_1 = 1.0
+    sample_weights_OK_2 = 2.0
 
-    n_sampless = [2, 3]
-    n_featuress = [3, 2]
+    reg = LinearRegression()
 
-    for n_samples, n_features in zip(n_sampless, n_featuress):
-        X = rng.randn(n_samples, n_features)
-        y = rng.randn(n_samples)
-        sample_weights_OK = rng.randn(n_samples) ** 2 + 1
-        sample_weights_OK_1 = 1.0
-        sample_weights_OK_2 = 2.0
-
-        reg = LinearRegression()
-
-        # make sure the "OK" sample weights actually work
-        reg.fit(X, y, sample_weights_OK)
-        reg.fit(X, y, sample_weights_OK_1)
-        reg.fit(X, y, sample_weights_OK_2)
+    # make sure the "OK" sample weights actually work
+    reg.fit(X, y, sample_weights_OK)
+    reg.fit(X, y, sample_weights_OK_1)
+    reg.fit(X, y, sample_weights_OK_2)
 
 
 def test_fit_intercept():
@@ -150,83 +143,66 @@ def test_fit_intercept():
 
 def test_error_on_wrong_normalize():
     normalize = "wrong"
-    default = True
     error_msg = "Leave 'normalize' to its default"
     with pytest.raises(ValueError, match=error_msg):
-        _deprecate_normalize(normalize, default, "estimator")
+        _deprecate_normalize(normalize, "estimator")
 
 
+# TODO(1.4): remove
 @pytest.mark.parametrize("normalize", [True, False, "deprecated"])
-@pytest.mark.parametrize("default", [True, False])
-# FIXME update test in 1.2 for new versions
-def test_deprecate_normalize(normalize, default):
+def test_deprecate_normalize(normalize):
     # test all possible case of the normalize parameter deprecation
-    if not default:
-        if normalize == "deprecated":
-            # no warning
-            output = default
-            expected = None
-            warning_msg = []
+    if normalize == "deprecated":
+        # no warning
+        output = False
+        expected = None
+        warning_msg = []
+    else:
+        output = normalize
+        expected = FutureWarning
+        warning_msg = ["1.4"]
+        if not normalize:
+            warning_msg.append("default value")
         else:
-            output = normalize
-            expected = FutureWarning
-            warning_msg = ["1.2"]
-            if not normalize:
-                warning_msg.append("default value")
-            else:
-                warning_msg.append("StandardScaler(")
-    elif default:
-        if normalize == "deprecated":
-            # warning to pass False and use StandardScaler
-            output = default
-            expected = FutureWarning
-            warning_msg = ["False", "1.2", "StandardScaler("]
-        else:
-            # no warning
-            output = normalize
-            expected = None
-            warning_msg = []
+            warning_msg.append("StandardScaler(")
 
-    with pytest.warns(expected) as record:
-        _normalize = _deprecate_normalize(normalize, default, "estimator")
+    if expected is None:
+        with warnings.catch_warnings():
+            warnings.simplefilter("error", FutureWarning)
+            _normalize = _deprecate_normalize(normalize, "estimator")
+    else:
+        with pytest.warns(expected) as record:
+            _normalize = _deprecate_normalize(normalize, "estimator")
+        assert all([warning in str(record[0].message) for warning in warning_msg])
     assert _normalize == output
 
-    n_warnings = 0 if expected is None else 1
-    assert len(record) == n_warnings
-    if n_warnings:
-        assert all([warning in str(record[0].message) for warning in warning_msg])
 
-
-def test_linear_regression_sparse(random_state=0):
+def test_linear_regression_sparse(global_random_seed):
     # Test that linear regression also works with sparse data
-    random_state = check_random_state(random_state)
-    for i in range(10):
-        n = 100
-        X = sparse.eye(n, n)
-        beta = random_state.rand(n)
-        y = X * beta[:, np.newaxis]
+    rng = np.random.RandomState(global_random_seed)
+    n = 100
+    X = sparse.eye(n, n)
+    beta = rng.rand(n)
+    y = X @ beta
 
-        ols = LinearRegression()
-        ols.fit(X, y.ravel())
-        assert_array_almost_equal(beta, ols.coef_ + ols.intercept_)
+    ols = LinearRegression()
+    ols.fit(X, y.ravel())
+    assert_array_almost_equal(beta, ols.coef_ + ols.intercept_)
 
-        assert_array_almost_equal(ols.predict(X) - y.ravel(), 0)
+    assert_array_almost_equal(ols.predict(X) - y.ravel(), 0)
 
 
-# FIXME: 'normalize' to be removed in 1.2 in LinearRegression
-@pytest.mark.filterwarnings("ignore:'normalize' was deprecated")
-@pytest.mark.parametrize("normalize", [True, False])
 @pytest.mark.parametrize("fit_intercept", [True, False])
-def test_linear_regression_sparse_equal_dense(normalize, fit_intercept):
+def test_linear_regression_sparse_equal_dense(fit_intercept):
     # Test that linear regression agrees between sparse and dense
-    rng = check_random_state(0)
+    rng = np.random.RandomState(0)
     n_samples = 200
     n_features = 2
     X = rng.randn(n_samples, n_features)
     X[X < 0.1] = 0.0
     Xcsr = sparse.csr_matrix(X)
     y = rng.rand(n_samples)
-    params = dict(normalize=normalize, fit_intercept=fit_intercept)
+    params = dict(fit_intercept=fit_intercept)
     clf_dense = LinearRegression(**params)
     clf_sparse = LinearRegression(**params)
     clf_dense.fit(X, y)
@@ -235,9 +211,10 @@ def test_linear_regression_sparse_equal_dense(normalize, fit_intercept):
     assert_allclose(clf_dense.coef_, clf_sparse.coef_)
 
 
-def test_linear_regression_multiple_outcome(random_state=0):
+def test_linear_regression_multiple_outcome():
     # Test multiple-outcome linear regressions
-    X, y = make_regression(random_state=random_state)
+    rng = np.random.RandomState(0)
+    X, y = make_regression(random_state=rng)
 
     Y = np.vstack((y, y)).T
     n_features = X.shape[1]
@@ -251,10 +228,10 @@ def test_linear_regression_multiple_outcome(random_state=0):
     assert_array_almost_equal(np.vstack((y_pred, y_pred)).T, Y_pred, decimal=3)
 
 
-def test_linear_regression_sparse_multiple_outcome(random_state=0):
+def test_linear_regression_sparse_multiple_outcome(global_random_seed):
     # Test multiple-outcome linear regressions with sparse data
-    random_state = check_random_state(random_state)
-    X, y = make_sparse_uncorrelated(random_state=random_state)
+    rng = np.random.RandomState(global_random_seed)
+    X, y = make_sparse_uncorrelated(random_state=rng)
     X = sparse.coo_matrix(X)
     Y = np.vstack((y, y)).T
     n_features = X.shape[1]
@@ -291,10 +268,10 @@ def test_linear_regression_positive():
     assert_allclose(reg.predict(X), [0])
 
 
-def test_linear_regression_positive_multiple_outcome(random_state=0):
+def test_linear_regression_positive_multiple_outcome(global_random_seed):
     # Test multiple-outcome nonnegative linear regressions
-    random_state = check_random_state(random_state)
-    X, y = make_sparse_uncorrelated(random_state=random_state)
+    rng = np.random.RandomState(global_random_seed)
+    X, y = make_sparse_uncorrelated(random_state=rng)
     Y = np.vstack((y, y)).T
     n_features = X.shape[1]
 
@@ -308,9 +285,10 @@ def test_linear_regression_positive_multiple_outcome(random_state=0):
     assert_allclose(np.vstack((y_pred, y_pred)).T, Y_pred)
 
 
-def test_linear_regression_positive_vs_nonpositive():
+def test_linear_regression_positive_vs_nonpositive(global_random_seed):
     # Test differences with LinearRegression when positive=False.
-    X, y = make_sparse_uncorrelated(random_state=0)
+    rng = np.random.RandomState(global_random_seed)
+    X, y = make_sparse_uncorrelated(random_state=rng)
 
     reg = LinearRegression(positive=True)
     reg.fit(X, y)
@@ -320,9 +298,10 @@ def test_linear_regression_positive_vs_nonpositive():
     assert np.mean((reg.coef_ - regn.coef_) ** 2) > 1e-3
 
 
-def test_linear_regression_positive_vs_nonpositive_when_positive():
+def test_linear_regression_positive_vs_nonpositive_when_positive(global_random_seed):
     # Test LinearRegression fitted coefficients
     # when the problem is positive.
+    rng = np.random.RandomState(global_random_seed)
     n_samples = 200
     n_features = 4
     X = rng.rand(n_samples, n_features)
@@ -338,9 +317,6 @@ def test_linear_regression_positive_vs_nonpositive_when_positive():
 
 def test_linear_regression_pd_sparse_dataframe_warning():
     pd = pytest.importorskip("pandas")
-    # restrict the pd versions < '0.24.0' as they have a bug in is_sparse func
-    if parse_version(pd.__version__) < parse_version("0.24.0"):
-        pytest.skip("pandas 0.24+ required.")
 
     # Warning is raised only when some of the columns is sparse
     df = pd.DataFrame({"0": np.random.randn(10)})
@@ -362,12 +338,13 @@ def test_linear_regression_pd_sparse_dataframe_warning():
     df["0"] = pd.arrays.SparseArray(df["0"], fill_value=0)
     assert hasattr(df, "sparse")
 
-    with pytest.warns(None) as record:
+    with warnings.catch_warnings():
+        warnings.simplefilter("error", UserWarning)
         reg.fit(df.iloc[:, 0:2], df.iloc[:, 3])
-    assert not record
 
 
-def test_preprocess_data():
+def test_preprocess_data(global_random_seed):
+    rng = np.random.RandomState(global_random_seed)
     n_samples = 200
     n_features = 2
     X = rng.rand(n_samples, n_features)
@@ -404,7 +381,8 @@ def test_preprocess_data():
     assert_array_almost_equal(yt, y - expected_y_mean)
 
 
-def test_preprocess_data_multioutput():
+def test_preprocess_data_multioutput(global_random_seed):
+    rng = np.random.RandomState(global_random_seed)
     n_samples = 200
     n_features = 3
     n_outputs = 2
@@ -432,7 +410,8 @@ def test_preprocess_data_multioutput():
 
 
 @pytest.mark.parametrize("is_sparse", [False, True])
-def test_preprocess_data_weighted(is_sparse):
+def test_preprocess_data_weighted(is_sparse, global_random_seed):
+    rng = np.random.RandomState(global_random_seed)
     n_samples = 200
     n_features = 4
     # Generate random data with 50% of zero values to make sure
@@ -478,7 +457,6 @@ def test_preprocess_data_weighted(is_sparse):
         fit_intercept=True,
         normalize=False,
         sample_weight=sample_weight,
-        return_mean=True,
     )
     assert_array_almost_equal(X_mean, expected_X_mean)
     assert_array_almost_equal(y_mean, expected_y_mean)
@@ -496,7 +474,6 @@ def test_preprocess_data_weighted(is_sparse):
         fit_intercept=True,
         normalize=True,
         sample_weight=sample_weight,
-        return_mean=True,
     )
 
     assert_array_almost_equal(X_mean, expected_X_mean)
@@ -537,18 +514,18 @@ def test_preprocess_data_weighted(is_sparse):
     assert_array_almost_equal(yt, y - expected_y_mean)
 
 
-def test_sparse_preprocess_data_with_return_mean():
+def test_sparse_preprocess_data_offsets(global_random_seed):
+    rng = np.random.RandomState(global_random_seed)
     n_samples = 200
     n_features = 2
-    # random_state not supported yet in sparse.rand
-    X = sparse.rand(n_samples, n_features, density=0.5)  # , random_state=rng
+    X = sparse.rand(n_samples, n_features, density=0.5, random_state=rng)
     X = X.tolil()
     y = rng.rand(n_samples)
     XA = X.toarray()
     expected_X_scale = np.std(XA, axis=0) * np.sqrt(X.shape[0])
 
     Xt, yt, X_mean, y_mean, X_scale = _preprocess_data(
-        X, y, fit_intercept=False, normalize=False, return_mean=True
+        X, y, fit_intercept=False, normalize=False
     )
     assert_array_almost_equal(X_mean, np.zeros(n_features))
     assert_array_almost_equal(y_mean, 0)
@@ -557,7 +534,7 @@ def test_sparse_preprocess_data_with_return_mean():
     assert_array_almost_equal(yt, y)
 
     Xt, yt, X_mean, y_mean, X_scale = _preprocess_data(
-        X, y, fit_intercept=True, normalize=False, return_mean=True
+        X, y, fit_intercept=True, normalize=False
     )
     assert_array_almost_equal(X_mean, np.mean(XA, axis=0))
     assert_array_almost_equal(y_mean, np.mean(y, axis=0))
@@ -566,7 +543,7 @@ def test_sparse_preprocess_data_with_return_mean():
     assert_array_almost_equal(yt, y - np.mean(y, axis=0))
 
     Xt, yt, X_mean, y_mean, X_scale = _preprocess_data(
-        X, y, fit_intercept=True, normalize=True, return_mean=True
+        X, y, fit_intercept=True, normalize=True
     )
     assert_array_almost_equal(X_mean, np.mean(XA, axis=0))
     assert_array_almost_equal(y_mean, np.mean(y, axis=0))
@@ -605,7 +582,8 @@ def test_preprocess_copy_data_no_checks(is_sparse, to_copy):
         assert np.may_share_memory(X_, X)
 
 
-def test_dtype_preprocess_data():
+def test_dtype_preprocess_data(global_random_seed):
+    rng = np.random.RandomState(global_random_seed)
     n_samples = 200
     n_features = 2
     X = rng.rand(n_samples, n_features)
@@ -624,7 +602,6 @@ def test_dtype_preprocess_data():
                 y_32,
                 fit_intercept=fit_intercept,
                 normalize=normalize,
-                return_mean=True,
             )
 
             Xt_64, yt_64, X_mean_64, y_mean_64, X_scale_64 = _preprocess_data(
@@ -632,7 +609,6 @@ def test_dtype_preprocess_data():
                 y_64,
                 fit_intercept=fit_intercept,
                 normalize=normalize,
-                return_mean=True,
             )
 
             Xt_3264, yt_3264, X_mean_3264, y_mean_3264, X_scale_3264 = _preprocess_data(
@@ -640,7 +616,6 @@ def test_dtype_preprocess_data():
                 y_64,
                 fit_intercept=fit_intercept,
                 normalize=normalize,
-                return_mean=True,
             )
 
             Xt_6432, yt_6432, X_mean_6432, y_mean_6432, X_scale_6432 = _preprocess_data(
@@ -648,7 +623,6 @@ def test_dtype_preprocess_data():
                 y_32,
                 fit_intercept=fit_intercept,
                 normalize=normalize,
-                return_mean=True,
             )
 
             assert Xt_32.dtype == np.float32
@@ -688,7 +662,8 @@ def test_dtype_preprocess_data():
 
 
 @pytest.mark.parametrize("n_targets", [None, 2])
-def test_rescale_data_dense(n_targets):
+def test_rescale_data_dense(n_targets, global_random_seed):
+    rng = np.random.RandomState(global_random_seed)
     n_samples = 200
     n_features = 2
 
@@ -698,12 +673,12 @@ def test_rescale_data_dense(n_targets):
         y = rng.rand(n_samples)
     else:
         y = rng.rand(n_samples, n_targets)
-    rescaled_X, rescaled_y = _rescale_data(X, y, sample_weight)
-    rescaled_X2 = X * np.sqrt(sample_weight)[:, np.newaxis]
+    rescaled_X, rescaled_y, sqrt_sw = _rescale_data(X, y, sample_weight)
+    rescaled_X2 = X * sqrt_sw[:, np.newaxis]
     if n_targets is None:
-        rescaled_y2 = y * np.sqrt(sample_weight)
+        rescaled_y2 = y * sqrt_sw
     else:
-        rescaled_y2 = y * np.sqrt(sample_weight)[:, np.newaxis]
+        rescaled_y2 = y * sqrt_sw[:, np.newaxis]
     assert_array_almost_equal(rescaled_X, rescaled_X2)
     assert_array_almost_equal(rescaled_y, rescaled_y2)
 
