@@ -2,7 +2,7 @@
 This file contains preprocessing tools based on polynomials.
 """
 import collections
-import numbers
+from numbers import Integral
 from itertools import chain, combinations
 from itertools import combinations_with_replacement as combinations_w_r
 
@@ -13,10 +13,9 @@ from scipy.special import comb
 
 from ..base import BaseEstimator, TransformerMixin
 from ..utils import check_array
-from ..utils.deprecation import deprecated
-from ..utils.fixes import linspace
 from ..utils.validation import check_is_fitted, FLOAT_DTYPES, _check_sample_weight
 from ..utils.validation import _check_feature_names_in
+from ..utils._param_validation import Interval, StrOptions
 from ..utils.stats import _weighted_percentile
 
 from ._csr_polynomial_expansion import _csr_polynomial_expansion
@@ -42,27 +41,27 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
     ----------
     degree : int or tuple (min_degree, max_degree), default=2
         If a single int is given, it specifies the maximal degree of the
-        polynomial features. If a tuple ``(min_degree, max_degree)`` is
-        passed, then ``min_degree`` is the minimum and ``max_degree`` is the
-        maximum polynomial degree of the generated features. Note that
-        min_degree=0 and 1 are equivalent as outputting the degree zero term
-        is determined by ``include_bias``.
+        polynomial features. If a tuple `(min_degree, max_degree)` is passed,
+        then `min_degree` is the minimum and `max_degree` is the maximum
+        polynomial degree of the generated features. Note that `min_degree=0`
+        and `min_degree=1` are equivalent as outputting the degree zero term is
+        determined by `include_bias`.
 
     interaction_only : bool, default=False
-        If true, only interaction features are produced: features that are
-        products of at most ``degree`` *distinct* input features, i.e. terms
-        with power of 2 or higher of the same input feature are excluded:
+        If `True`, only interaction features are produced: features that are
+        products of at most `degree` *distinct* input features, i.e. terms with
+        power of 2 or higher of the same input feature are excluded:
 
-            - included: ``x[0]``, `x[1]`, ``x[0] * x[1]``, etc.
-            - excluded: ``x[0] ** 2``, ``x[0] ** 2 * x[1]``, etc.
+            - included: `x[0]`, `x[1]`, `x[0] * x[1]`, etc.
+            - excluded: `x[0] ** 2`, `x[0] ** 2 * x[1]`, etc.
 
     include_bias : bool, default=True
-        If True (default), then include a bias column, the feature in which
+        If `True` (default), then include a bias column, the feature in which
         all polynomial powers are zero (i.e. a column of ones - acts as an
         intercept term in a linear model).
 
     order : {'C', 'F'}, default='C'
-        Order of output array in the dense case. 'F' order is faster to
+        Order of output array in the dense case. `'F'` order is faster to
         compute, but may slow down subsequent estimators.
 
         .. versionadded:: 0.21
@@ -70,14 +69,7 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
     Attributes
     ----------
     powers_ : ndarray of shape (`n_output_features_`, `n_features_in_`)
-        powers_[i, j] is the exponent of the jth input in the ith output.
-
-    n_input_features_ : int
-        The total number of input features.
-
-        .. deprecated:: 1.0
-            This attribute is deprecated in 1.0 and will be removed in 1.2.
-            Refer to `n_features_in_` instead.
+        `powers_[i, j]` is the exponent of the jth input in the ith output.
 
     n_features_in_ : int
         Number of features seen during :term:`fit`.
@@ -98,7 +90,7 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
     See Also
     --------
     SplineTransformer : Transformer that generates univariate B-spline bases
-        for features
+        for features.
 
     Notes
     -----
@@ -130,6 +122,13 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
            [ 1.,  4.,  5., 20.]])
     """
 
+    _parameter_constraints: dict = {
+        "degree": [Interval(Integral, 0, None, closed="left"), "array-like"],
+        "interaction_only": ["boolean"],
+        "include_bias": ["boolean"],
+        "order": [StrOptions({"C", "F"})],
+    }
+
     def __init__(
         self, degree=2, *, interaction_only=False, include_bias=True, order="C"
     ):
@@ -181,6 +180,7 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
 
     @property
     def powers_(self):
+        """Exponent for each of the inputs in the output."""
         check_is_fitted(self)
 
         combinations = self._combinations(
@@ -194,42 +194,6 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
             [np.bincount(c, minlength=self.n_features_in_) for c in combinations]
         )
 
-    @deprecated(
-        "get_feature_names is deprecated in 1.0 and will be removed "
-        "in 1.2. Please use get_feature_names_out instead."
-    )
-    def get_feature_names(self, input_features=None):
-        """
-        Return feature names for output features
-
-        Parameters
-        ----------
-        input_features : list of str of shape (n_features,), default=None
-            String names for input features if available. By default,
-            "x0", "x1", ... "xn_features" is used.
-
-        Returns
-        -------
-        output_feature_names : list of str of shape (n_output_features,)
-        """
-        powers = self.powers_
-        if input_features is None:
-            input_features = ["x%d" % i for i in range(powers.shape[1])]
-        feature_names = []
-        for row in powers:
-            inds = np.where(row)[0]
-            if len(inds):
-                name = " ".join(
-                    "%s^%d" % (input_features[ind], exp)
-                    if exp != 1
-                    else input_features[ind]
-                    for ind, exp in zip(inds, row[inds])
-                )
-            else:
-                name = "1"
-            feature_names.append(name)
-        return feature_names
-
     def get_feature_names_out(self, input_features=None):
         """Get output feature names for transformation.
 
@@ -238,9 +202,10 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
         input_features : array-like of str or None, default=None
             Input features.
 
-            - If `input_features` is `None`, then `feature_names_in_` is
+            - If `input_features is None`, then `feature_names_in_` is
               used as feature names in. If `feature_names_in_` is not defined,
-              then names are generated: `[x0, x1, ..., x(n_features_in_)]`.
+              then the following input feature names are generated:
+              `["x0", "x1", ..., "x(n_features_in_ - 1)"]`.
             - If `input_features` is an array-like, then `input_features` must
               match `feature_names_in_` if `feature_names_in_` is defined.
 
@@ -270,27 +235,29 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
         """
         Compute number of output features.
 
-
         Parameters
         ----------
         X : {array-like, sparse matrix} of shape (n_samples, n_features)
             The data.
 
-        y : None
-            Ignored.
+        y : Ignored
+            Not used, present here for API consistency by convention.
 
         Returns
         -------
         self : object
             Fitted transformer.
         """
+        self._validate_params()
         _, n_features = self._validate_data(X, accept_sparse=True).shape
 
-        if isinstance(self.degree, numbers.Integral):
-            if self.degree < 0:
+        if isinstance(self.degree, Integral):
+            if self.degree == 0 and not self.include_bias:
                 raise ValueError(
-                    f"degree must be a non-negative integer, got {self.degree}."
+                    "Setting degree to zero and include_bias to False would result in"
+                    " an empty output array."
                 )
+
             self._min_degree = 0
             self._max_degree = self.degree
         elif (
@@ -298,8 +265,8 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
         ):
             self._min_degree, self._max_degree = self.degree
             if not (
-                isinstance(self._min_degree, numbers.Integral)
-                and isinstance(self._max_degree, numbers.Integral)
+                isinstance(self._min_degree, Integral)
+                and isinstance(self._max_degree, Integral)
                 and self._min_degree >= 0
                 and self._min_degree <= self._max_degree
             ):
@@ -309,6 +276,11 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
                     "min_degree <= max_degree, got "
                     f"{self.degree}."
                 )
+            elif self._max_degree == 0 and not self.include_bias:
+                raise ValueError(
+                    "Setting both min_degree and max_degree to zero and include_bias to"
+                    " False would result in an empty output array."
+                )
         else:
             raise ValueError(
                 "degree must be a non-negative int or tuple "
@@ -359,10 +331,10 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
         Returns
         -------
         XP : {ndarray, sparse matrix} of shape (n_samples, NP)
-            The matrix of features, where NP is the number of polynomial
+            The matrix of features, where `NP` is the number of polynomial
             features generated from the combination of inputs. If a sparse
             matrix is provided, it will be converted into a sparse
-            ``csr_matrix``.
+            `csr_matrix`.
         """
         check_is_fitted(self)
 
@@ -380,7 +352,7 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
                 to_stack.append(
                     sparse.csc_matrix(np.ones(shape=(n_samples, 1), dtype=X.dtype))
                 )
-            if self._min_degree <= 1:
+            if self._min_degree <= 1 and self._max_degree > 0:
                 to_stack.append(X)
             for deg in range(max(2, self._min_degree), self._max_degree + 1):
                 Xp_next = _csr_polynomial_expansion(
@@ -442,6 +414,9 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
             else:
                 current_col = 0
 
+            if self._max_degree == 0:
+                return XP
+
             # degree 1 term
             XP[:, current_col : current_col + n_features] = X
             index = list(range(current_col, current_col + n_features))
@@ -486,16 +461,6 @@ class PolynomialFeatures(TransformerMixin, BaseEstimator):
                 XP = Xout
         return XP
 
-    # TODO: Remove in 1.2
-    # mypy error: Decorated property not supported
-    @deprecated(  # type: ignore
-        "The attribute `n_input_features_` was "
-        "deprecated in version 1.0 and will be removed in 1.2."
-    )
-    @property
-    def n_input_features_(self):
-        return self.n_features_in_
-
 
 # TODO:
 # - sparse support (either scipy or own cython solution)?
@@ -613,6 +578,17 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
            [0.  , 0.  , 0.5 , 0.5 ]])
     """
 
+    _parameter_constraints: dict = {
+        "n_knots": [Interval(Integral, 2, None, closed="left")],
+        "degree": [Interval(Integral, 0, None, closed="left")],
+        "knots": [StrOptions({"uniform", "quantile"}), "array-like"],
+        "extrapolation": [
+            StrOptions({"error", "constant", "linear", "continue", "periodic"})
+        ],
+        "include_bias": ["boolean"],
+        "order": [StrOptions({"C", "F"})],
+    }
+
     def __init__(
         self,
         n_knots=5,
@@ -667,7 +643,7 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
             x_min = np.amin(X[mask], axis=0)
             x_max = np.amax(X[mask], axis=0)
 
-            knots = linspace(
+            knots = np.linspace(
                 start=x_min,
                 stop=x_max,
                 num=n_knots,
@@ -677,32 +653,6 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
 
         return knots
 
-    @deprecated(
-        "get_feature_names is deprecated in 1.0 and will be removed "
-        "in 1.2. Please use get_feature_names_out instead."
-    )
-    def get_feature_names(self, input_features=None):
-        """Return feature names for output features.
-
-        Parameters
-        ----------
-        input_features : list of str of shape (n_features,), default=None
-            String names for input features if available. By default,
-            "x0", "x1", ... "xn_features" is used.
-
-        Returns
-        -------
-        output_feature_names : list of str of shape (n_output_features,)
-        """
-        n_splines = self.bsplines_[0].c.shape[0]
-        if input_features is None:
-            input_features = ["x%d" % i for i in range(self.n_features_in_)]
-        feature_names = []
-        for i in range(self.n_features_in_):
-            for j in range(n_splines - 1 + self.include_bias):
-                feature_names.append(f"{input_features[i]}_sp_{j}")
-        return feature_names
-
     def get_feature_names_out(self, input_features=None):
         """Get output feature names for transformation.
 
@@ -713,7 +663,8 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
 
             - If `input_features` is `None`, then `feature_names_in_` is
               used as feature names in. If `feature_names_in_` is not defined,
-              then names are generated: `[x0, x1, ..., x(n_features_in_)]`.
+              then the following input feature names are generated:
+              `["x0", "x1", ..., "x(n_features_in_ - 1)"]`.
             - If `input_features` is an array-like, then `input_features` must
               match `feature_names_in_` if `feature_names_in_` is defined.
 
@@ -722,7 +673,8 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
         feature_names_out : ndarray of str objects
             Transformed feature names.
         """
-        n_splines = self.bsplines_[0].c.shape[0]
+        n_splines = self.bsplines_[0].c.shape[1]
+
         input_features = _check_feature_names_in(self, input_features)
         feature_names = []
         for i in range(self.n_features_in_):
@@ -751,6 +703,8 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
         self : object
             Fitted transformer.
         """
+        self._validate_params()
+
         X = self._validate_data(
             X,
             reset=True,
@@ -763,20 +717,7 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
 
         _, n_features = X.shape
 
-        if not (isinstance(self.degree, numbers.Integral) and self.degree >= 0):
-            raise ValueError(
-                f"degree must be a non-negative integer, got {self.degree}."
-            )
-
-        if isinstance(self.knots, str) and self.knots in [
-            "uniform",
-            "quantile",
-        ]:
-            if not (isinstance(self.n_knots, numbers.Integral) and self.n_knots >= 2):
-                raise ValueError(
-                    f"n_knots must be a positive integer >= 2, got: {self.n_knots}"
-                )
-
+        if isinstance(self.knots, str):
             base_knots = self._get_base_knot_positions(
                 X, n_knots=self.n_knots, knots=self.knots, sample_weight=sample_weight
             )
@@ -789,21 +730,6 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
             elif not np.all(np.diff(base_knots, axis=0) > 0):
                 raise ValueError("knots must be sorted without duplicates.")
 
-        if self.extrapolation not in (
-            "error",
-            "constant",
-            "linear",
-            "continue",
-            "periodic",
-        ):
-            raise ValueError(
-                "extrapolation must be one of 'error', "
-                "'constant', 'linear', 'continue' or 'periodic'."
-            )
-
-        if not isinstance(self.include_bias, (bool, np.bool_)):
-            raise ValueError("include_bias must be bool.")
-
         # number of knots for base interval
         n_knots = base_knots.shape[0]
 
@@ -852,13 +778,13 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
             dist_max = base_knots[-1] - base_knots[-2]
 
             knots = np.r_[
-                linspace(
+                np.linspace(
                     base_knots[0] - degree * dist_min,
                     base_knots[0] - dist_min,
                     num=degree,
                 ),
                 base_knots,
-                linspace(
+                np.linspace(
                     base_knots[-1] + dist_max,
                     base_knots[-1] + degree * dist_max,
                     num=degree,
@@ -920,7 +846,6 @@ class SplineTransformer(TransformerMixin, BaseEstimator):
             spl = self.bsplines_[i]
 
             if self.extrapolation in ("continue", "error", "periodic"):
-
                 if self.extrapolation == "periodic":
                     # With periodic extrapolation we map x to the segment
                     # [spl.t[k], spl.t[n]].
